==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/model/query/HcrwQuery.java <==
package cn.gtmap.landtax.model.query;/**
 * Created by janeshen on 2014/8/22.
 */

import java.math.BigDecimal;
import java.util.Date;

/**
 * .
 * <p/>
 *
 * @author shenjian
 * @version V1.0, 2014/8/22
 */

public class HcrwQuery {

    private String hcxmlx;
    private String activityDefinitionId;
    private String workflowInstanceId;
    private String roleId;
    private String userId;

    //宗地核查
    private String gtbdId;
    private String djh;
    private String tdyt;
    private String qlrmc;
    private String tdzl;

    //供地核查
    private String xmId;
    private String xmmc;
    private String qdfs;
    private BigDecimal qdjg;
    private Date gdsj;
    private String xmTdyt;
    private String xmYddw;
    private String xmXzqdm;

    //报批核查
    private String pcId;
    private String pcmc;
    private String pcXzqdm;
    private String pcYddw;

    private String excelBegin;
    private String excelEnd;

    private String ids;

    public String getHcxmlx() {
        return hcxmlx;
    }

    public void setHcxmlx(String hcxmlx) {
        this.hcxmlx = hcxmlx;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getWorkflowInstanceId() {
        return workflowInstanceId;
    }

    public void setWorkflowInstanceId(String workflowInstanceId) {
        this.workflowInstanceId = workflowInstanceId;
    }

    public String getRoleId() {
        return roleId;
    }

    public void setRoleId(String roleId) {
        this.roleId = roleId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getQdfs() {
        return qdfs;
    }

    public void setQdfs(String qdfs) {
        this.qdfs = qdfs;
    }

    public BigDecimal getQdjg() {
        return qdjg;
    }

    public void setQdjg(BigDecimal qdjg) {
        this.qdjg = qdjg;
    }

    public Date getGdsj() {
        return gdsj;
    }

    public void setGdsj(Date gdsj) {
        this.gdsj = gdsj;
    }

    public String getXmTdyt() {
        return xmTdyt;
    }

    public void setXmTdyt(String xmTdyt) {
        this.xmTdyt = xmTdyt;
    }

    public String getXmYddw() {
        return xmYddw;
    }

    public void setXmYddw(String xmYddw) {
        this.xmYddw = xmYddw;
    }

    public String getXmXzqdm() {
        return xmXzqdm;
    }

    public void setXmXzqdm(String xmXzqdm) {
        this.xmXzqdm = xmXzqdm;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getGtbdId() {
        return gtbdId;
    }

    public void setGtbdId(String gtbdId) {
        this.gtbdId = gtbdId;
    }

    public String getXmId() {
        return xmId;
    }

    public void setXmId(String xmId) {
        this.xmId = xmId;
    }

    public String getPcId() {
        return pcId;
    }

    public void setPcId(String pcId) {
        this.pcId = pcId;
    }

    public String getPcmc() {
        return pcmc;
    }

    public void setPcmc(String pcmc) {
        this.pcmc = pcmc;
    }

    public String getPcXzqdm() {
        return pcXzqdm;
    }

    public void setPcXzqdm(String pcXzqdm) {
        this.pcXzqdm = pcXzqdm;
    }

    public String getPcYddw() {
        return pcYddw;
    }

    public void setPcYddw(String pcYddw) {
        this.pcYddw = pcYddw;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/model/query/HcrwQuery.java <==
package cn.gtmap.landtax.model.query;/**
 * Created by janeshen on 2014/8/22.
 */

import java.math.BigDecimal;
import java.util.Date;

/**
 * .
 * <p/>
 *
 * @author shenjian
 * @version V1.0, 2014/8/22
 */

public class HcrwQuery {

    private String hcxmlx;
    private String activityDefinitionId;
    private String workflowInstanceId;
    private String roleId;
    private String userId;

    //宗地核查
    private String gtbdId;
    private String djh;
    private String tdyt;
    private String qlrmc;
    private String tdzl;
    private String jdDm;

    //供地核查
    private String xmId;
    private String xmmc;
    private String qdfs;
    private BigDecimal qdjg;
    private Date gdsj;
    private String xmTdyt;
    private String xmYddw;
    private String xmXzqdm;

    //报批核查
    private String pcId;
    private String pcmc;
    private String pcXzqdm;
    private String pcYddw;

    private String excelBegin;
    private String excelEnd;

    private String ids;
    //税务登记核查
    private String nsrsbh;
    private String nsrmc;
    private String jdxzDm;
    private String zgkgDm;


    public String getHcxmlx() {
        return hcxmlx;
    }

    public void setHcxmlx(String hcxmlx) {
        this.hcxmlx = hcxmlx;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getWorkflowInstanceId() {
        return workflowInstanceId;
    }

    public void setWorkflowInstanceId(String workflowInstanceId) {
        this.workflowInstanceId = workflowInstanceId;
    }

    public String getRoleId() {
        return roleId;
    }

    public void setRoleId(String roleId) {
        this.roleId = roleId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getQdfs() {
        return qdfs;
    }

    public void setQdfs(String qdfs) {
        this.qdfs = qdfs;
    }

    public BigDecimal getQdjg() {
        return qdjg;
    }

    public void setQdjg(BigDecimal qdjg) {
        this.qdjg = qdjg;
    }

    public Date getGdsj() {
        return gdsj;
    }

    public void setGdsj(Date gdsj) {
        this.gdsj = gdsj;
    }

    public String getXmTdyt() {
        return xmTdyt;
    }

    public void setXmTdyt(String xmTdyt) {
        this.xmTdyt = xmTdyt;
    }

    public String getXmYddw() {
        return xmYddw;
    }

    public void setXmYddw(String xmYddw) {
        this.xmYddw = xmYddw;
    }

    public String getXmXzqdm() {
        return xmXzqdm;
    }

    public void setXmXzqdm(String xmXzqdm) {
        this.xmXzqdm = xmXzqdm;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getGtbdId() {
        return gtbdId;
    }

    public void setGtbdId(String gtbdId) {
        this.gtbdId = gtbdId;
    }

    public String getXmId() {
        return xmId;
    }

    public void setXmId(String xmId) {
        this.xmId = xmId;
    }

    public String getPcId() {
        return pcId;
    }

    public void setPcId(String pcId) {
        this.pcId = pcId;
    }

    public String getPcmc() {
        return pcmc;
    }

    public void setPcmc(String pcmc) {
        this.pcmc = pcmc;
    }

    public String getPcXzqdm() {
        return pcXzqdm;
    }

    public void setPcXzqdm(String pcXzqdm) {
        this.pcXzqdm = pcXzqdm;
    }

    public String getPcYddw() {
        return pcYddw;
    }

    public void setPcYddw(String pcYddw) {
        this.pcYddw = pcYddw;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getJdxzDm() {
        return jdxzDm;
    }

    public void setJdxzDm(String jdxzDm) {
        this.jdxzDm = jdxzDm;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getJdDm() {
        return jdDm;
    }

    public void setJdDm(String jdDm) {
        this.jdDm = jdDm;
    }
}
